Documentation
¶
Overview ¶
Package linode implements a DNS record management client compatible with the libdns interfaces for Linode.
Index ¶
- func ToDomainRecord(r linodego.DomainRecord) (libdns.Record, error)
- type Client
- type Provider
- func (p *Provider) AppendRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- func (p *Provider) DeleteRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- func (p *Provider) GetRecords(ctx context.Context, zone string) ([]libdns.Record, error)
- func (p *Provider) SetRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
- type Record
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToDomainRecord ¶
func ToDomainRecord(r linodego.DomainRecord) (libdns.Record, error)
Types ¶
type Provider ¶
type Provider struct {
Client
// APIToken is the Linode API token - see https://www.linode.com/docs/guides/getting-started-with-the-linode-api/#create-an-api-token
// Is recommended to only use a token with the Domain access in read/write mode.
APIToken string `json:"api_token,omitempty"`
}
Provider facilitates DNS record manipulation for Linode.
func (*Provider) AppendRecords ¶
func (p *Provider) AppendRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
AppendRecords adds records to the zone. It returns the records that were added.
func (*Provider) DeleteRecords ¶
func (p *Provider) DeleteRecords(ctx context.Context, zone string, records []libdns.Record) ([]libdns.Record, error)
DeleteRecords deletes the records from the zone. It returns the records that were deleted.
func (*Provider) GetRecords ¶
GetRecords lists all the records in the zone.
Click to show internal directories.
Click to hide internal directories.